package com.ruoyi.app.domain;

import com.ruoyi.common.annotation.Excel;
import com.ruoyi.common.core.domain.BaseEntity;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;

/**
 * 【请填写功能名称】对象 app_location
 *
 * @author ruoyi
 * @date 2025-01-14
 */
public class AppLocation extends BaseEntity
{
    private static final Long serialVersionUID = 1L;

    /** 排 */
    @Excel(name = "货架排")
    private Integer wRow;

    /** 列 */
    @Excel(name = "货架列")
    private Integer wCol;

    /** 层 */
    @Excel(name = "货架层")
    private Integer wLayer;

    /** 库位编码 */
    @Excel(name = "库位编码")
    private String locationId;

    /** 备注 */
    @Excel(name = "备注")
    private String remark;

    /** 库位状态 0 空闲 1 占用*/
    @Excel(name = "库位状态")
    private Integer locationStatus;

    /** 库位状态 0 启用 1 禁用*/
    @Excel(name = "启用状态", readConverterExp = "0=启用,1=禁用")
    private Integer isEnable;

    /** 库位类型 */
    private Integer locationType;

    /** 库位编码 */
    private String outerId;

    /** 库区号 */
    private Integer areaId;

    /** 巷道号 */
    private Integer tunnelId;

    /** 设备号 */
    private Integer equipmentId;

    /** 深度 */
    private Integer wDepth;

    /** 是否锁定 */
    private Integer isLock;

    /** 载具号 */
    private String vehicleId;

    /** 是否在工作中 */
    private Integer isWorking;

    public void setLocationId(String locationId)
    {
        this.locationId = locationId;
    }

    public String getLocationId()
    {
        return locationId;
    }
    public void setLocationType(Integer locationType)
    {
        this.locationType = locationType;
    }

    public Integer getLocationType()
    {
        return locationType;
    }
    public void setLocationStatus(Integer locationStatus)
    {
        this.locationStatus = locationStatus;
    }

    public Integer getLocationStatus()
    {
        return locationStatus;
    }
    public void setOuterId(String outerId)
    {
        this.outerId = outerId;
    }

    public String getOuterId()
    {
        return outerId;
    }
    public void setAreaId(Integer areaId)
    {
        this.areaId = areaId;
    }

    public Integer getAreaId()
    {
        return areaId;
    }
    public void setTunnelId(Integer tunnelId)
    {
        this.tunnelId = tunnelId;
    }

    public Integer getTunnelId()
    {
        return tunnelId;
    }
    public void setEquipmentId(Integer equipmentId)
    {
        this.equipmentId = equipmentId;
    }

    public Integer getEquipmentId()
    {
        return equipmentId;
    }
    public void setwRow(Integer wRow)
    {
        this.wRow = wRow;
    }

    public Integer getwRow()
    {
        return wRow;
    }
    public void setwCol(Integer wCol)
    {
        this.wCol = wCol;
    }

    public Integer getwCol()
    {
        return wCol;
    }
    public void setwLayer(Integer wLayer)
    {
        this.wLayer = wLayer;
    }

    public Integer getwLayer()
    {
        return wLayer;
    }
    public void setwDepth(Integer wDepth)
    {
        this.wDepth = wDepth;
    }

    public Integer getwDepth()
    {
        return wDepth;
    }
    public void setIsLock(Integer isLock)
    {
        this.isLock = isLock;
    }

    public Integer getIsLock()
    {
        return isLock;
    }
    public void setVehicleId(String vehicleId)
    {
        this.vehicleId = vehicleId;
    }

    public String getVehicleId()
    {
        return vehicleId;
    }

    @Override
    public String getRemark() {
        return remark;
    }

    @Override
    public void setRemark(String remark) {
        this.remark = remark;
    }

    public Integer getIsWorking() {
        return isWorking;
    }

    public void setIsWorking(Integer isWorking) {
        this.isWorking = isWorking;
    }

    public Integer getIsEnable() {
        return isEnable;
    }

    public void setIsEnable(Integer isEnable) {
        this.isEnable = isEnable;
    }

    @Override
    public String toString() {
        return new ToStringBuilder(this,ToStringStyle.MULTI_LINE_STYLE)
                .append("locationId", getLocationId())
                .append("locationType", getLocationType())
                .append("locationStatus", getLocationStatus())
                .append("outerId", getOuterId())
                .append("areaId", getAreaId())
                .append("tunnelId", getTunnelId())
                .append("equipmentId", getEquipmentId())
                .append("wRow", getwRow())
                .append("wCol", getwCol())
                .append("wLayer", getwLayer())
                .append("wDepth", getwDepth())
                .append("isLock", getIsLock())
                .append("vehicleId", getVehicleId())
                .append("remark", getRemark())
                .append("isWorking", getIsWorking())
                .append("isEnable", getIsEnable())
                .toString();
    }
}
